PROGRAM Compute_Coma_Profiles
! A code for computing:
! 1st column: x=r/r500
! 2nd column: r [h^-1 Mpc]
! 3rd column: electron number density profile [cm^-3]
! 4th column: X-ray temperature profile [keV]
! 5th column: electron pressure profile [eV cm^-3] 
! E. Komatsu, November 20, 2011
  IMPLICIT none
  double precision :: n0,rc,beta1,p0,alpha,beta2,gamma,rs
  double precision :: x,r,r500,da,ne,Te,Pe
  integer :: i
  r500=1.037d0 ! h^-1 Mpc; computed from M500=6.61d14 h^-1 Msun. 
               ! M500 is from M500-Tx relation of Vikhlinin et al with Tx=8.4keV
  print*,'r500=',r500,' h^-1 Mpc'
  da=67.363  ! h^-1 Mpc; for OmegaM=0.277 and z=0.0231
!!$ beta model parameters [Briel et al. 1992; converted to LCDM by A.Finoguenov]
  n0=3.42e-3  ! central electron density; sqrt(h/0.72) cm^-3 
  beta1=0.75d0 ! beta for a beta model 
  rc=0.2058d0  ! core radius for 10.5 arcmin; h^-1 Mpc
!!$ GNFW parameters [provided by A.Finoguenov]
  p0=6.1135007E-11*6.24d11 ! sqrt(h/0.72) eV cm^-3
  alpha=1.20d0
  beta2=5.49d0 ! fixed when fitted to the measured Pe profile
  gamma=-6.9427d-2
  rs=0.99d0*0.72d0 ! h^-1 Mpc
  open(1,file='x_r_ne_te_pe_coma.txt')
  do i=1,1000
     x=1d-3*dble(i)*6d0 ! x=r/r500
     r=x*r500 ! h^-1 Mpc
     ne=n0*(1+(r/rc)**2d0)**(-3d0*beta1/2d0)
     pe=p0*(r/rs)**(-gamma)*(1d0+(r/rs)**alpha)**((gamma-beta2)/alpha)
     Te=pe/ne/1d3 ! keV
     write(1,'(5E18.5)')x,x*r500,ne,Te,Pe
  enddo
  close(1)
END PROGRAM Compute_Coma_Profiles
